@@ -7,6 +7,7 @@ import logging
 
 class AmFastError(Exception):
     """Base exception for this package."""
+
     # To get around 2.6 deprecation warning
     def _get_message(self):
         return self._message
@@ -46,15 +47,49 @@ class NullHandler(logging.Handler):
 
 log_debug = False # True to log verbose debug strings.
 log_raw = False # True to log raw AMF byte strings.
+logged_attr = '_amfast_logged' # Add to exceptions to indicate that it has been logged.
 logger = logging.getLogger('AmFast')
 logger.addHandler(NullHandler())
 logger.setLevel(logging.DEBUG)
 
-def log_exc():
+month_names = [
+    'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
+    'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
+
+def get_log_timestamp():
+    dt = datetime.now()
+    return '[%s/%s/%s:%s:%s:%s]' % (dt.day, month_names[dt.month - 1],
+        dt.year, dt.hour, dt.minute, dt.second)
+
+def log_exc(e):
     """Log an exception."""
+    if hasattr(e, logged_attr):
+        return
+    else:
+        setattr(e, logged_attr, True)
+
     error_type, error_value, trbk = sys.exc_info()
     tb_list = traceback.format_tb(trbk)
-    msg = "Exception: %s -\n-\nDescription: %s -\n-\nTraceback: " %\
-        (error_type.__name__, error_value)
-    msg += "-\n".join(tb_list)
-    logger.error(msg)
+    
+    msg = [get_log_timestamp() + " EXCEPTION"]
+    msg.append("# ---- EXCEPTION DESCRIPTION BEGIN ---- #")
+    
+    msg.append("# ---- Type ---- #\n%s\n# ---- Detail ---- #\n%s" % \
+        (error_type.__name__, error_value))
+    msg.append("# ---- Traceback ---- #")
+    msg.append("-\n".join(tb_list))
+    msg.append("# ---- EXCEPTION DESCRIPTION END ---- #")
+    return "\n".join(msg)
+
+# --- Setup threading implementation --- #
+
+try:
+    import threading
+except ImportError:
+    if log_debug:
+        logger.debug("AmFast is using dummy_threading module.")
+
+# Set this to dummy_threading.RLock
+# to skip locking when using Twisted
+# or any other single threaded implementation. 
+mutex_cls = threading.RLock
